<?php
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

/**
 * @group disable
 * @category  Shopware
 * @package   Shopware\Tests
 * @copyright Copyright (c) 2012, shopware AG (http://www.shopware.de)
 */
class Shopware_Tests_Models_Category_ActiveByArticleIdQueryTest extends Enlight_Components_Test_TestCase
{
    /**
     * @var \Shopware\Models\Category\Repository
     */
    protected $repo = null;

    /**
     * @return Shopware\Models\Category\Repository
     */
    protected function getRepo()
    {
        if ($this->repo === null) {
            $this->repo = Shopware()->Models()->Category();
        }
        return $this->repo;
    }

    protected $expected = array(
        5 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        219 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 24,
                'parentId' => 10,
                'name' => 'Versandkosten',
                'position' => 7,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Versandkosteneinstellungen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        4 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        199 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        203 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 65,
                'parentId' => 61,
                'name' => 'Configurator articles',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 22,
                'parentId' => 10,
                'name' => 'Konfiguratorartikel',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Das Plugin Artikelkonfigurator',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        205 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 65,
                'parentId' => 61,
                'name' => 'Configurator articles',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 22,
                'parentId' => 10,
                'name' => 'Konfiguratorartikel',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Das Plugin Artikelkonfigurator',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        243 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        8 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        10 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        7 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        15 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        17 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        18 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        19 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        20 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        21 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        22 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        23 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        25 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        26 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        27 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        28 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        29 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        30 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        31 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        32 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        33 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        34 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        35 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        36 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        37 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        38 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        39 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        40 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        41 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        42 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        43 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        44 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 51,
                'parentId' => 43,
                'name' => 'Delights',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        63 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        64 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        65 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        66 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        67 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        68 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        69 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        70 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        72 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        73 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        74 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        75 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        76 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        77 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        79 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        80 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        81 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        82 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        83 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        84 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        85 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        86 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        87 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        88 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        89 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        90 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        91 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        92 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        93 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        94 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        95 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        96 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        97 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        101 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        102 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        103 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        104 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        107 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        108 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        109 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        110 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        112 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        113 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        114 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        115 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        116 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        118 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        119 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        120 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        121 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        122 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        123 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        128 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        129 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 58,
                'parentId' => 46,
                'name' => 'Beauty & Care',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        130 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        131 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 58,
                'parentId' => 46,
                'name' => 'Beauty & Care',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        134 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        135 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        136 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        137 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        141 => array(
            0 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        142 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        143 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        144 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        148 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        150 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        152 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        153 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        154 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        155 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        156 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        157 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 60,
                'parentId' => 46,
                'name' => 'Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        158 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        159 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 60,
                'parentId' => 46,
                'name' => 'Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        160 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        161 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        163 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        164 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        166 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 60,
                'parentId' => 46,
                'name' => 'Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        167 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        168 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        169 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        171 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        172 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 58,
                'parentId' => 46,
                'name' => 'Beauty & Care',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        173 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        180 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        181 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 59,
                'parentId' => 46,
                'name' => 'Travel around the World',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        194 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 69,
                'parentId' => 61,
                'name' => 'Crossselling',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 19,
                'parentId' => 10,
                'name' => 'Crossselling',
                'position' => 6,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Crossselling',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        195 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        196 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 69,
                'parentId' => 61,
                'name' => 'Crossselling',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 19,
                'parentId' => 10,
                'name' => 'Crossselling',
                'position' => 6,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Crossselling',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        197 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        198 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        201 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        202 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 65,
                'parentId' => 61,
                'name' => 'Configurator articles',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 22,
                'parentId' => 10,
                'name' => 'Konfiguratorartikel',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Das Plugin Artikelkonfigurator',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        204 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 65,
                'parentId' => 61,
                'name' => 'Configurator articles',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 22,
                'parentId' => 10,
                'name' => 'Konfiguratorartikel',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Das Plugin Artikelkonfigurator',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        206 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 73,
                'parentId' => 61,
                'name' => 'Price strategies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 23,
                'parentId' => 10,
                'name' => 'Preisgestaltung',
                'position' => 10,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möglichkeiten der Preisgestaltung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        208 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 73,
                'parentId' => 61,
                'name' => 'Price strategies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 23,
                'parentId' => 10,
                'name' => 'Preisgestaltung',
                'position' => 10,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möglichkeiten der Preisgestaltung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        209 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 73,
                'parentId' => 61,
                'name' => 'Price strategies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 23,
                'parentId' => 10,
                'name' => 'Preisgestaltung',
                'position' => 10,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möglichkeiten der Preisgestaltung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        210 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 64,
                'parentId' => 61,
                'name' => 'Customer loyalty',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 30,
                'parentId' => 10,
                'name' => 'Kundenbindung',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Funktionen zur Kundenbindung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        211 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 64,
                'parentId' => 61,
                'name' => 'Customer loyalty',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 30,
                'parentId' => 10,
                'name' => 'Kundenbindung',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Funktionen zur Kundenbindung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        213 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        217 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        222 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        224 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        225 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        226 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        229 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        231 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        233 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        234 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        235 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        236 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        237 => array(
            0 => array(
                'id' => 38,
                'parentId' => 8,
                'name' => 'Dekoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Mit der richtigen Dekoration in eine Wohlfühlwelt',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 56,
                'parentId' => 45,
                'name' => 'Decoration',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        238 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        239 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        240 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        241 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        242 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 53,
                'parentId' => 44,
                'name' => 'Entertainment',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        245 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        246 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        247 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 64,
                'parentId' => 61,
                'name' => 'Customer loyalty',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 30,
                'parentId' => 10,
                'name' => 'Kundenbindung',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Funktionen zur Kundenbindung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        248 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 54,
                'parentId' => 45,
                'name' => 'Furniture',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        11 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        14 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        12 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        13 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 48,
                'parentId' => 47,
                'name' => 'Teas',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 12,
                'parentId' => 11,
                'name' => 'Tees',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        2 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 67,
                'parentId' => 61,
                'name' => 'Product comparison',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            8 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            9 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        3 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        6 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        9 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 50,
                'parentId' => 43,
                'name' => 'Brandies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 14,
                'parentId' => 5,
                'name' => 'Edelbrände',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Die besten Edelbrände',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 21,
                'parentId' => 10,
                'name' => 'Produktvergleiche & Filter',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Eigenschaften und Filter',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        24 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 47,
                'parentId' => 43,
                'name' => 'Teas and Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 49,
                'parentId' => 47,
                'name' => 'Teas and accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 11,
                'parentId' => 5,
                'name' => 'Tees und Zubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tees und Zubehör',
                'active' => true,
                'template' => 'article_listing_3col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            6 => array(
                'id' => 13,
                'parentId' => 11,
                'name' => 'Tee-Zubehör',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Tee-Zubehör',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            7 => array(
                'id' => 43,
                'parentId' => 39,
                'name' => 'Worlds of indulgence',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        71 => array(
            0 => array(
                'id' => 32,
                'parentId' => 8,
                'name' => 'Möbel',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möbel',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        98 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        100 => array(
            0 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        105 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        106 => array(
            0 => array(
                'id' => 36,
                'parentId' => 6,
                'name' => 'On World Tour',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        117 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 16,
                'parentId' => 9,
                'name' => 'Entertainment',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        132 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        145 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 52,
                'parentId' => 44,
                'name' => 'Vintage',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 31,
                'parentId' => 9,
                'name' => 'Vintage',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 9,
                'parentId' => 3,
                'name' => 'Freizeitwelten',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Freizeitwelten',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 44,
                'parentId' => 39,
                'name' => 'Leisure worlds',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        151 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        162 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        165 => array(
            0 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        174 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        175 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        176 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        177 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        178 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 57,
                'parentId' => 46,
                'name' => 'Beachwear',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        179 => array(
            0 => array(
                'id' => 34,
                'parentId' => 6,
                'name' => 'Beachwear',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        170 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 60,
                'parentId' => 46,
                'name' => 'Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 37,
                'parentId' => 6,
                'name' => 'Accessoires',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        200 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 68,
                'parentId' => 61,
                'name' => 'Presentation',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 20,
                'parentId' => 10,
                'name' => 'Darstellung',
                'position' => 5,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Artikeldarstellung im Listing.',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        207 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 73,
                'parentId' => 61,
                'name' => 'Price strategies',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 23,
                'parentId' => 10,
                'name' => 'Preisgestaltung',
                'position' => 10,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Möglichkeiten der Preisgestaltung',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        78 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 55,
                'parentId' => 45,
                'name' => 'Kitchen Accessories',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 33,
                'parentId' => 8,
                'name' => 'Küchenzubehör',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Vielfältiges Zubehör für Ihre Küche',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 8,
                'parentId' => 3,
                'name' => 'Wohnwelten',
                'position' => 2,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Wohnwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 45,
                'parentId' => 39,
                'name' => 'Home sweet home',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        214 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        215 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        216 => array(
            0 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        218 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 58,
                'parentId' => 46,
                'name' => 'Beauty & Care',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 35,
                'parentId' => 6,
                'name' => 'Beauty & Care',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 6,
                'parentId' => 3,
                'name' => 'Sommerwelten',
                'position' => 3,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Sommerwelten',
                'active' => true,
                'template' => 'article_listing_4col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 46,
                'parentId' => 39,
                'name' => 'Summertime',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        220 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 24,
                'parentId' => 10,
                'name' => 'Versandkosten',
                'position' => 7,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Versandkosteneinstellungen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        221 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 24,
                'parentId' => 10,
                'name' => 'Versandkosten',
                'position' => 7,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Versandkosteneinstellungen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        223 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 72,
                'parentId' => 61,
                'name' => 'Shipping costs',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 24,
                'parentId' => 10,
                'name' => 'Versandkosten',
                'position' => 7,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Versandkosteneinstellungen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        227 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 71,
                'parentId' => 61,
                'name' => 'Payment methods',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 25,
                'parentId' => 10,
                'name' => 'Zahlungsarten',
                'position' => 8,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Zahlungsarten & Riskmanagement',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        228 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 71,
                'parentId' => 61,
                'name' => 'Payment methods',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 25,
                'parentId' => 10,
                'name' => 'Zahlungsarten',
                'position' => 8,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Zahlungsarten & Riskmanagement',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        230 => array(
            0 => array(
                'id' => 39,
                'parentId' => 1,
                'name' => 'English',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 61,
                'parentId' => 39,
                'name' => 'Examples',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => null,
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 71,
                'parentId' => 61,
                'name' => 'Payment methods',
                'position' => null,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            3 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            4 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            5 => array(
                'id' => 25,
                'parentId' => 10,
                'name' => 'Zahlungsarten',
                'position' => 8,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Zahlungsarten & Riskmanagement',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        244 => array(
            0 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 10,
                'parentId' => 3,
                'name' => 'Beispiele',
                'position' => 4,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Beispiele',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 74,
                'parentId' => 10,
                'name' => 'Kundengruppen / B2B',
                'position' => 7,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Kundengruppen',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
        249 => array(),
        250 => array(),
        251 => array(),
        252 => array(),
        253 => array(),
        254 => array(),
        255 => array(),
        256 => array(),
        257 => array(),
        258 => array(),
        259 => array(),
        260 => array(),
        261 => array(),
        262 => array(),
        263 => array(),
        264 => array(),
        265 => array(),
        266 => array(),
        267 => array(),
        268 => array(),
        269 => array(),
        270 => array(),
        271 => array(),
        272 => array(
            0 => array(
                'id' => 5,
                'parentId' => 3,
                'name' => 'Genusswelten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Genusswelten',
                'active' => true,
                'template' => 'article_listing_1col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            1 => array(
                'id' => 15,
                'parentId' => 5,
                'name' => 'Köstlichkeiten',
                'position' => 0,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => 'Köstlichkeiten',
                'active' => true,
                'template' => 'article_listing_2col.tpl',
                'blog' => false,
                'showFilterGroups' => true,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
            2 => array(
                'id' => 3,
                'parentId' => 1,
                'name' => 'Deutsch',
                'position' => 1,
                'metaKeywords' => null,
                'metaDescription' => '',
                'cmsHeadline' => '',
                'active' => true,
                'template' => '',
                'blog' => false,
                'showFilterGroups' => false,
                'external' => '',
                'hideFilter' => false,
                'hideTop' => false,
                'noViewSelect' => false,
                'emotions' => null,
                'articles' => null,
            ),
        ),
    );

    public function testQuery()
    {
        foreach ($this->expected as $id => $expected) {
            $query = $this->getRepo()->getActiveByArticleIdQuery($id);
            $data = $this->removeDates($query->getArrayResult());
            $this->assertEquals($data, $expected);
        }
    }

    protected function removeDates($data)
    {
        foreach ($data as &$subCategory) {
            unset($subCategory['changed']);
            unset($subCategory['cmsText']);
            unset($subCategory['added']);
            foreach ($subCategory['emotions'] as &$emotion) {
                unset($emotion['createDate']);
                unset($emotion['modified']);
            }
            foreach ($subCategory['articles'] as &$article) {
                unset($article['added']);
                unset($article['changed']);
                unset($article['description']);
                unset($article['descriptionLong']);
                unset($article['mainDetail']['releaseDate']);
            }
        }
        return $data;
    }
}
